@@ -31,12 +31,12 @@ class QAbstractAnimation;
 class CellItem : public QGraphicsPixmapItem, public ReloadableItem
 {
 public:
-    CellItem(int x, int y, QSharedPointer<Picmi> game, QGraphicsItem *parent = 0);
+    CellItem(int x, int y, QSharedPointer<Picmi> game, QGraphicsItem *parent = nullptr);
 
     /* updates displayed pixmap according to current cell state */
     virtual void refresh();
 
-    void reload(const QSize &size) Q_DECL_OVERRIDE;
+    void reload(const QSize &size) override;
 
 protected:
     virtual int getTilesize() const = 0;
@@ -50,11 +50,11 @@ class OverviewCellItem : public CellItem
 public:
     /* creates the item with field coordinates (x,y) and the specified
       game and scene */
-    OverviewCellItem(int x, int y, QSharedPointer<Picmi> game, QGraphicsItem *parent = 0);
+    OverviewCellItem(int x, int y, QSharedPointer<Picmi> game, QGraphicsItem *parent = nullptr);
 
 protected:
-    int getTilesize() const Q_DECL_OVERRIDE;
-    QPixmap getPixmap() const Q_DECL_OVERRIDE;
+    int getTilesize() const override;
+    QPixmap getPixmap() const override;
 };
 
 class GameCellItem : public QObject, public CellItem
@@ -65,21 +65,21 @@ class GameCellItem : public QObject, public CellItem
 public:
     /* creates the item with field coordinates (x,y) and the specified
       game and scene */
-    GameCellItem(int x, int y, QSharedPointer<Picmi> game, Scene *scene, QGraphicsItem *parent = 0);
+    GameCellItem(int x, int y, QSharedPointer<Picmi> game, Scene *scene, QGraphicsItem *parent = nullptr);
 
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *event) override;
 
-    void refresh() Q_DECL_OVERRIDE;
-    void reload(const QSize &size) Q_DECL_OVERRIDE;
+    void refresh() override;
+    void reload(const QSize &size) override;
 
 protected:
-    void mousePressEvent(QGraphicsSceneMouseEvent *event) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QGraphicsSceneMouseEvent *event) Q_DECL_OVERRIDE;
-    void hoverEnterEvent(QGraphicsSceneHoverEvent *event) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event) Q_DECL_OVERRIDE;
+    void mousePressEvent(QGraphicsSceneMouseEvent *event) override;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent *event) override;
+    void hoverEnterEvent(QGraphicsSceneHoverEvent *event) override;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event) override;
 
-    int getTilesize() const Q_DECL_OVERRIDE;
-    QPixmap getPixmap() const Q_DECL_OVERRIDE;
+    int getTilesize() const override;
+    QPixmap getPixmap() const override;
 
 private:
     /** Converts scene- to game coordinates. */
